@@ -23,8 +23,8 @@
  * Represents the target of an ongoing DND operation.
  *
  * Possible drop sites get informed about the status of the ongoing drag
- * operation with events of type %GDK_DRAG_ENTER, %GDK_DRAG_LEAVE,
- * %GDK_DRAG_MOTION and %GDK_DROP_START. The `GdkDrop` object can be obtained
+ * operation with events of type `GDK_DRAG_ENTER`, `GDK_DRAG_LEAVE`,
+ * `GDK_DRAG_MOTION` and `GDK_DROP_START`. The `GdkDrop` object can be obtained
  * from these [class@Gdk.Event] types using [method@Gdk.DNDEvent.get_drop].
  *
  * The actual data transfer is initiated from the target side via an async
@@ -485,11 +485,11 @@ gdk_drop_get_surface (GdkDrop *self)
  * Returns the possible actions for this `GdkDrop`.
  *
  * If this value contains multiple actions - i.e.
- * [func@Gdk.DragAction.is_unique] returns %FALSE for the result -
+ * [func@Gdk.DragAction.is_unique] returns false for the result -
  * [method@Gdk.Drop.finish] must choose the action to use when
  * accepting the drop. This will only happen if you passed
- * %GDK_ACTION_ASK as one of the possible actions in
- * [method@Gdk.Drop.status]. %GDK_ACTION_ASK itself will not
+ * `GDK_ACTION_ASK` as one of the possible actions in
+ * [method@Gdk.Drop.status]. `GDK_ACTION_ASK` itself will not
  * be included in the actions returned by this function.
  *
  * This value may change over the lifetime of the [class@Gdk.Drop]
@@ -504,7 +504,7 @@ gdk_drop_get_actions (GdkDrop *self)
 {
   GdkDropPrivate *priv = gdk_drop_get_instance_private (self);
 
-  g_return_val_if_fail (GDK_IS_DROP (self), 0);
+  g_return_val_if_fail (GDK_IS_DROP (self), GDK_ACTION_NONE);
 
   return priv->actions;
 }
@@ -534,7 +534,7 @@ gdk_drop_set_actions (GdkDrop       *self,
  * If this is an in-app drag-and-drop operation, returns the `GdkDrag`
  * that corresponds to this drop.
  *
- * If it is not, %NULL is returned.
+ * If it is not, `NULL` is returned.
  *
  * Returns: (transfer none) (nullable): the corresponding `GdkDrag`
  */
@@ -551,8 +551,8 @@ gdk_drop_get_drag (GdkDrop *self)
 /**
  * gdk_drop_status:
  * @self: a `GdkDrop`
- * @actions: Supported actions of the destination, or 0 to indicate
- *    that a drop will not be accepted
+ * @actions: Supported actions of the destination, or `GDK_ACTION_NONE` to
+ *    indicate that a drop will not be accepted
  * @preferred: A unique action that's a member of @actions indicating the
  *    preferred action
  *
@@ -566,7 +566,7 @@ gdk_drop_get_drag (GdkDrop *self)
  * action to use when multiple actions are possible.
  *
  * This function should be called by drag destinations in response to
- * %GDK_DRAG_ENTER or %GDK_DRAG_MOTION events. If the destination does
+ * `GDK_DRAG_ENTER` or `GDK_DRAG_MOTION` events. If the destination does
  * not yet know the exact actions it supports, it should set any possible
  * actions first and then later call this function again.
  */
@@ -590,7 +590,8 @@ gdk_drop_status (GdkDrop       *self,
 /**
  * gdk_drop_finish:
  * @self: a `GdkDrop`
- * @action: the action performed by the destination or 0 if the drop failed
+ * @action: the action performed by the destination or `GDK_ACTION_NONE` if the
+ *   drop failed
  *
  * Ends the drag operation after a drop.
  *
