@@ -33,9 +33,12 @@
 /**
  * GtkPicture:
  *
- * The `GtkPicture` widget displays a `GdkPaintable`.
+ * Displays a `GdkPaintable`.
  *
- * ![An example GtkPicture](picture.png)
+ * picture>
+ *   <source srcset="picture-dark.png" media="(prefers-color-scheme: dark)">
+ *   <img alt="An example GtkPicture" src="picture.png">
+ * </picture>
  *
  * Many convenience functions are provided to make pictures simple to use.
  * For example, if you want to load an image from a file, and then display
@@ -49,8 +52,8 @@
  * “broken image” icon similar to that used in many web browsers.
  * If you want to handle errors in loading the file yourself,
  * for example by displaying an error message, then load the image with
- * [ctor@Gdk.Texture.new_from_file], then create the `GtkPicture` with
- * [ctor@Gtk.Picture.new_for_paintable].
+ * and image loading framework such as libglycin, then create the `GtkPicture`
+ * with [ctor@Gtk.Picture.new_for_paintable].
  *
  * Sometimes an application will want to avoid depending on external data
  * files, such as image files. See the documentation of `GResource` for details.
@@ -78,7 +81,7 @@
  *
  * ## Accessibility
  *
- * `GtkPicture` uses the `GTK_ACCESSIBLE_ROLE_IMG` role.
+ * `GtkPicture` uses the [enum@Gtk.AccessibleRole.img] role.
  */
 
 enum
@@ -553,10 +556,12 @@ gtk_picture_new_for_pixbuf (GdkPixbuf *pixbuf)
 
   g_return_val_if_fail (pixbuf == NULL || GDK_IS_PIXBUF (pixbuf), NULL);
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   if (pixbuf)
     paintable = GDK_PAINTABLE (gdk_texture_new_for_pixbuf (pixbuf));
   else
     paintable = NULL;
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   result = gtk_picture_new_for_paintable (paintable);
 
@@ -575,9 +580,9 @@ gtk_picture_new_for_pixbuf (GdkPixbuf *pixbuf)
  * If the file isn’t found or can’t be loaded, the resulting
  * `GtkPicture` is empty.
  *
- * If you need to detect failures to load the file, use
- * [ctor@Gdk.Texture.new_from_file] to load the file yourself,
- * then create the `GtkPicture` from the texture.
+ * If you need to detect failures to load the file, use an
+ * image loading framework such as libglycin to load the file
+ * yourself, then create the `GtkPicture` from the texture.
  *
  * Returns: a new `GtkPicture`
  */
@@ -671,6 +676,12 @@ gtk_picture_new_for_resource (const char *resource_path)
  * Makes @self load and display @file.
  *
  * See [ctor@Gtk.Picture.new_for_file] for details.
+ *
+ * ::: warning
+ *     Note that this function should not be used with untrusted data.
+ *     Use a proper image loading framework such as libglycin, which can
+ *     load many image formats into a `GdkTexture`, and then use
+ *     [method@Gtk.Image.set_from_paintable].
  */
 void
 gtk_picture_set_file (GtkPicture *self,
@@ -727,6 +738,12 @@ gtk_picture_get_file (GtkPicture *self)
  * Makes @self load and display the given @filename.
  *
  * This is a utility function that calls [method@Gtk.Picture.set_file].
+ *
+ * ::: warning
+ *     Note that this function should not be used with untrusted data.
+ *     Use a proper image loading framework such as libglycin, which can
+ *     load many image formats into a `GdkTexture`, and then use
+ *     [method@Gtk.Image.set_from_paintable].
  */
 void
 gtk_picture_set_filename (GtkPicture *self,
@@ -810,10 +827,12 @@ gtk_picture_set_pixbuf (GtkPicture *self,
   g_return_if_fail (GTK_IS_PICTURE (self));
   g_return_if_fail (pixbuf == NULL || GDK_IS_PIXBUF (pixbuf));
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   if (pixbuf)
     texture = gdk_texture_new_for_pixbuf (pixbuf);
   else
     texture = NULL;
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   gtk_picture_set_paintable (self, GDK_PAINTABLE (texture));
 
@@ -842,7 +861,7 @@ paintable_size_equal (GdkPaintable *one,
  *
  * Makes @self display the given @paintable.
  *
- * If @paintable is %NULL, nothing will be displayed.
+ * If @paintable is `NULL`, nothing will be displayed.
  *
  * See [ctor@Gtk.Picture.new_for_paintable] for details.
  */
