@@ -26,8 +26,18 @@
 #include "gtktypebuiltins.h"
 #include "gtksettings.h"
 #include "gdkcairoprivate.h"
+#include "gdkcolorprivate.h"
 
 
+static void
+get_text_bounds (PangoLayout     *layout,
+                 graphene_rect_t *bounds)
+{
+  PangoRectangle ink_rect;
+  pango_layout_get_pixel_extents (layout, &ink_rect, NULL);
+  graphene_rect_init (bounds, ink_rect.x, ink_rect.y, ink_rect.width, ink_rect.height);
+}
+
 void
 gtk_css_style_snapshot_layout (GtkCssBoxes *boxes,
                                GtkSnapshot *snapshot,
@@ -36,8 +46,7 @@ gtk_css_style_snapshot_layout (GtkCssBoxes *boxes,
                                PangoLayout *layout)
 {
   GtkCssStyle *style;
-  GdkColor color;
-  gboolean has_shadow;
+  GdkColor text_color;
 
   gtk_snapshot_push_debug (snapshot, "Layout");
 
@@ -48,20 +57,55 @@ gtk_css_style_snapshot_layout (GtkCssBoxes *boxes,
     }
 
   style = boxes->style;
-  gtk_css_color_to_color (gtk_css_color_value_get_color (style->used->color), &color);
+  gtk_css_color_to_color (gtk_css_color_value_get_color (style->used->color), &text_color);
 
-  has_shadow = gtk_css_shadow_value_push_snapshot (style->used->text_shadow, snapshot);
+  if (!gtk_css_shadow_value_is_clear (style->used->text_shadow))
+    {
+      graphene_point_t offset;
+      GdkColor color;
+      double radius;
 
-  gtk_snapshot_append_layout2 (snapshot, layout, &color);
+      gtk_css_shadow_value_get_offset (style->used->text_shadow, 0, &offset);
+      gtk_css_shadow_value_get_color (style->used->text_shadow, 0, &color);
+      radius = gtk_css_shadow_value_get_radius (style->used->text_shadow, 0);
 
-  if (has_shadow)
-    gtk_snapshot_pop (snapshot);
+      gtk_snapshot_save (snapshot);
+      gtk_snapshot_translate (snapshot, &offset);
+
+      if (radius != 0)
+        gtk_snapshot_push_blur (snapshot, radius);
+
+      if (gtk_pango_layout_has_color_glyphs (layout))
+        {
+          GdkColor black = GDK_COLOR_SRGB (0, 0, 0, 1);
+          graphene_rect_t bounds;
+
+          get_text_bounds (layout, &bounds);
+          gtk_snapshot_push_mask (snapshot, GSK_MASK_MODE_ALPHA);
+          gtk_snapshot_add_layout (snapshot, layout, &black);
+          gtk_snapshot_pop (snapshot);
+          gtk_snapshot_add_color (snapshot, &color, &bounds);
+          gtk_snapshot_pop (snapshot);
+          gdk_color_finish (&black);
+        }
+      else
+        {
+          gtk_snapshot_add_layout (snapshot, layout, &color);
+        }
+
+      if (radius != 0)
+        gtk_snapshot_pop (snapshot);
+
+      gtk_snapshot_restore (snapshot);
+    }
+
+  gtk_snapshot_add_layout (snapshot, layout, &text_color);
+
+  gdk_color_finish (&text_color);
 
   if (x != 0 || y != 0)
     gtk_snapshot_restore (snapshot);
 
-  gdk_color_finish (&color);
-
   gtk_snapshot_pop (snapshot);
 }
 
@@ -223,9 +267,9 @@ snapshot_insertion_cursor (GtkSnapshot     *snapshot,
       else
         offset = stem_width - stem_width / 2;
 
-      gtk_snapshot_append_color2 (snapshot,
-                                  &color,
-                                  &GRAPHENE_RECT_INIT (- offset, 0, stem_width, height));
+      gtk_snapshot_add_color (snapshot,
+                              &color,
+                              &GRAPHENE_RECT_INIT (- offset, 0, stem_width, height));
     }
 }
 
@@ -265,6 +309,7 @@ gtk_css_style_snapshot_caret (GtkCssBoxes    *boxes,
   pango_layout_get_caret_pos (layout, index, &strong_pos, &weak_pos);
 
   direction2 = PANGO_DIRECTION_NEUTRAL;
+  cursor2 = NULL; /* poor MSVC */
 
   if (split_cursor)
     {
